{% extends "admin/base_site.html" %}
{% load i18n static %}

{% block extrastyle %}
  {{ block.super }}
  <link rel="stylesheet" type="text/css" href="{% static "admin/css/changelists.css" %}">
  {{ media.css }}
{% endblock %}

{% block extrahead %}
{{ block.super }}
{{ media.js }}
{% endblock %}

{% block bodyclass %}{{ block.super }} app-{{ app_label }} change-list{% endblock %}

{% if not is_popup %}
{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
&rsaquo; <a href="{% url 'admin:admin-data-index-view' %}">{{ app_label|capfirst }}</a>
&rsaquo; {{ slug|capfirst }}
</div>
{% endblock %}
{% endif %}

{% block content %}
  <div id="content-main">
    <div class="module" id="changelist">
      <div class="changelist-form-container">
        <form id="changelist-form" method="post" novalidate>{% csrf_token %}
          <div class="results">
            <table id="result_list">
              <thead>
                <tr>
                {% for header in headers %}
                  <th scope="col">
                    <div class="text">
                      <span>{{ header|capfirst }}</span>
                    </div>
                  </th>
                {% endfor %}
                </tr>
              </thead>
              <tbody>
              {% for row in rows %}
                <tr>
                {% for item in row %}
                  <td>{{ item }}</td>
                {% endfor %}
                </tr>
              {% endfor %}
              </tbody>
            </table>
           </div>
        </form>
      </div>
    </div>
  </div>
{% endblock %}
